==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualGatewaySpecListenerConnectionPool.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property grpcs
 * @property http2s
 * @property https
 */
public data class GetVirtualGatewaySpecListenerConnectionPool(
    public val grpcs: List<GetVirtualGatewaySpecListenerConnectionPoolGrpc>,
    public val http2s: List<GetVirtualGatewaySpecListenerConnectionPoolHttp2>,
    public val https: List<GetVirtualGatewaySpecListenerConnectionPoolHttp>,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualGatewaySpecListenerConnectionPool):
            GetVirtualGatewaySpecListenerConnectionPool = GetVirtualGatewaySpecListenerConnectionPool(
            grpcs = javaType.grpcs().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecListenerConnectionPoolGrpc.Companion.toKotlin(args0)
                })
            }),
            http2s = javaType.http2s().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecListenerConnectionPoolHttp2.Companion.toKotlin(args0)
                })
            }),
            https = javaType.https().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecListenerConnectionPoolHttp.Companion.toKotlin(args0)
                })
            }),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualGatewaySpecListenerConnectionPool.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property grpcs
 * @property http2s
 * @property https
 */
public data class GetVirtualGatewaySpecListenerConnectionPool(
    public val grpcs: List<GetVirtualGatewaySpecListenerConnectionPoolGrpc>,
    public val http2s: List<GetVirtualGatewaySpecListenerConnectionPoolHttp2>,
    public val https: List<GetVirtualGatewaySpecListenerConnectionPoolHttp>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualGatewaySpecListenerConnectionPool): GetVirtualGatewaySpecListenerConnectionPool = GetVirtualGatewaySpecListenerConnectionPool(
            grpcs = javaType.grpcs().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecListenerConnectionPoolGrpc.Companion.toKotlin(args0)
                })
            }),
            http2s = javaType.http2s().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecListenerConnectionPoolHttp2.Companion.toKotlin(args0)
                })
            }),
            https = javaType.https().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecListenerConnectionPoolHttp.Companion.toKotlin(args0)
                })
            }),
        )
    }
}
